@@ -394,7 +394,9 @@ class CDROM:
                     command_args = [
                         self.wodim, "-eject",
                         "dev=%(device)s" % vars(self)]
-                    subprocess.call(command_args, stderr=open(os.devnull))
+                    subprocess.call(
+                        command_args,
+                        stdout=open(os.devnull), stderr=open(os.devnull))
                     sys.exit()
 
             self.size = get_media_capacity()
